#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-default-instances-base
version: 0.1.0
id: data-default-instances-base-0.1.0-198bff61242257f5772aacd6c941b1bb
key: datad_2INJRDvgZ4jDHH2QJIQkcK
license: BSD3
maintainer: <l.mai@web.de>
synopsis: Default instances for types in base
category: Data
author: Lukas Mai
exposed: True
exposed-modules:
    Data.Default.Instances.Base
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/data-default-instances-base-0.1.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/data-default-instances-base-0.1.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/data-default-instances-base-0.1.0
hs-libraries: HSdata-default-instances-base-0.1.0-2INJRDvgZ4jDHH2QJIQkcK
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
haddock-interfaces: /usr/share/doc/haskell-data-default-instances-base/html/data-default-instances-base.haddock
haddock-html: /usr/share/doc/haskell-data-default-instances-base/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
